==> jc-1.4.0.tar.gz: soot/jimple/internal/AbstractJimpleBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleBinopExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b58ca291a2bb7e54 soot_jimple_internal_AbstractJimpleBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods {
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/AbstractJimpleBinopExpr.h <==
// public abstract class soot.jimple.internal.AbstractJimpleBinopExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b58ca291a2bb7e54 soot_jimple_internal_AbstractJimpleBinopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractBinopExpr

#include "soot/jimple/internal/AbstractBinopExpr.h"

#ifndef _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_
#define _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$object;

typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable;
typedef const struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_AbstractJimpleBinopExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods {
};

// Vtable
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleBinopExpr;
};

// Vtype
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs {
    _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleBinopExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_AbstractJimpleBinopExpr$object {
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype	*vtype;
	_jc_soot_jimple_internal_AbstractJimpleBinopExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_AbstractJimpleBinopExpr$vtype _jc_soot_jimple_internal_AbstractJimpleBinopExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_AbstractJimpleBinopExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_AbstractJimpleBinopExpr$class_object;

#endif	/* _JC_soot_jimple_internal_AbstractJimpleBinopExpr_H_ */
